@@ -4,21 +4,17 @@ class __ValidFailFast:
 
     def __call__(self, fail_fast) -> bool:
         """
-        Validator that ensures the `fail_fast` parameter is a boolean.
-
-        This class is intended to be used as a callable validator to check that the
-        provided `fail_fast` argument is of type `bool`. If the value is not a boolean,
-        an `OrionisTestValueError` is raised with a descriptive error message.
+        Validates that the `fail_fast` parameter is a boolean.
 
         Parameters
         ----------
         fail_fast : Any
-            The value to be validated as a boolean.
+            The value to validate as a boolean.
 
         Returns
         -------
         bool
-            The validated boolean value of `fail_fast`.
+            The validated boolean value.
 
         Raises
         ------
@@ -34,4 +30,4 @@ class __ValidFailFast:
         return fail_fast
 
 # Exported singleton instance
-ValidFailFast = __ValidFailFast()
+ValidFailFast = __ValidFailFast()
\ No newline at end of file
